@@ -1,12 +1,12 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2021 openpyxl
 
 """
-Package medata
+Package metadata
 """
 
 __author__ = "See AUTHORS"
 __author_email__ = "charlie.clark@clark-consulting.eu"
-__license__ = "MIT/Expat"
+__license__ = "MIT"
 __maintainer_email__ = "openpyxl-users@googlegroups.com"
 __url__ = "https://openpyxl.readthedocs.io"
-__version__ = "2.6.3"
+__version__ = "3.0.6"
